"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = void 0;
var _postcss = _interopRequireDefault(require("postcss"));
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
const postcssFontLoaderPlugn = (exports, fontFamilyHash, fallbackFonts = [])=>{
    return {
        postcssPlugin: "postcss-font-loader",
        Once (root) {
            const fontFamilies = [];
            let rawFamily;
            let fontWeight;
            let fontStyle;
            const formatFamily = (family)=>{
                if (family[0] === "'" || family[0] === '"') {
                    family = family.slice(1, family.length - 1);
                }
                // Turn the font family unguessable to make it localy scoped
                return `'__${family.replace(/ /g, "_")}_${fontFamilyHash}'`;
            };
            for (const node of root.nodes){
                if (node.type === "atrule" && node.name === "font-face") {
                    const familyNode = node.nodes.find((decl)=>decl.prop === "font-family");
                    if (!familyNode) {
                        continue;
                    }
                    if (!rawFamily) {
                        let family = familyNode.value;
                        if (family[0] === "'" || family[0] === '"') {
                            family = family.slice(1, family.length - 1);
                        }
                        rawFamily = family;
                    }
                    const formattedFamily = formatFamily(familyNode.value);
                    familyNode.value = formattedFamily;
                    if (fontFamilies.includes(formattedFamily)) {
                        continue;
                    }
                    fontFamilies.push(formattedFamily);
                    // Only extract weight and style from first encountered family, the rest will treated as fallbacks
                    if (fontFamilies.length > 1) {
                        continue;
                    }
                    // Extract weight and style from first encountered @font-face
                    const weight = node.nodes.find((decl)=>decl.prop === "font-weight");
                    // Skip if the value includes ' ', then it's a range of possible values
                    if (weight && !weight.value.includes(" ")) {
                        fontWeight = weight.value;
                    }
                    const style = node.nodes.find((decl)=>decl.prop === "font-style");
                    // Skip if the value includes ' ', then it's a range of possible values
                    if (style && !style.value.includes(" ")) {
                        fontStyle = style.value;
                    }
                }
            }
            const [mainFontFamily, ...adjustFontFallbacks] = fontFamilies;
            // If fallback fonts were provided from the font loader, they should be used before the adjustFontFallbacks
            const formattedFontFamilies = [
                mainFontFamily,
                ...fallbackFonts,
                ...adjustFontFallbacks, 
            ].join(", ");
            // Add class with family, weight and style
            const classRule = new _postcss.default.Rule({
                selector: ".className"
            });
            classRule.nodes = [
                new _postcss.default.Declaration({
                    prop: "font-family",
                    value: formattedFontFamilies
                }),
                ...fontWeight ? [
                    new _postcss.default.Declaration({
                        prop: "font-weight",
                        value: fontWeight
                    }), 
                ] : [],
                ...fontStyle ? [
                    new _postcss.default.Declaration({
                        prop: "font-style",
                        value: fontStyle
                    }), 
                ] : [], 
            ];
            root.nodes.push(classRule);
            // Add class that defines a variable with the font family
            const varialbeRule = new _postcss.default.Rule({
                selector: ".variable"
            });
            varialbeRule.nodes = [
                new _postcss.default.Declaration({
                    prop: rawFamily ? `--next-font-${rawFamily.toLowerCase().replace(/ /g, "-")}${fontWeight ? `-${fontWeight}` : ""}${fontStyle === "italic" ? `-${fontStyle}` : ""}` : "",
                    value: formattedFontFamilies
                }), 
            ];
            root.nodes.push(varialbeRule);
            // Export @font-face values as is
            exports.push({
                name: "style",
                value: {
                    fontFamily: formattedFontFamilies,
                    fontWeight: fontWeight && Number(fontWeight),
                    fontStyle
                }
            });
        }
    };
};
postcssFontLoaderPlugn.postcss = true;
var _default = postcssFontLoaderPlugn;
exports.default = _default;

//# sourceMappingURL=postcss-font-loader.js.map